==> sjog_0.5.orig.tar.gz: sjog-0.5/src/sjog_sonypi.h <==
#ifndef _SJOG_SONYPI_H
#define _SJOG_SONYPI_H 1

#include "sjog.h"

#define SONYPI_EVENT_JOGDIAL_DOWN        1
#define SONYPI_EVENT_JOGDIAL_UP          2
#define SONYPI_EVENT_JOGDIAL_DOWN_PRESSED    3
#define SONYPI_EVENT_JOGDIAL_UP_PRESSED      4
#define SONYPI_EVENT_JOGDIAL_PRESSED         5
#define SONYPI_EVENT_JOGDIAL_RELEASED        6
#define SONYPI_EVENT_CAPTURE_PRESSED         7
#define SONYPI_EVENT_CAPTURE_RELEASED        8
#define SONYPI_EVENT_CAPTURE_PARTIALPRESSED  9
#define SONYPI_EVENT_CAPTURE_PARTIALRELEASED    10
#define SONYPI_EVENT_FNKEY_ESC          11
#define SONYPI_EVENT_FNKEY_F1           12
#define SONYPI_EVENT_FNKEY_F2           13
#define SONYPI_EVENT_FNKEY_F3           14
#define SONYPI_EVENT_FNKEY_F4           15
#define SONYPI_EVENT_FNKEY_F5           16
#define SONYPI_EVENT_FNKEY_F6           17
#define SONYPI_EVENT_FNKEY_F7           18
#define SONYPI_EVENT_FNKEY_F8           19
#define SONYPI_EVENT_FNKEY_F9           20
#define SONYPI_EVENT_FNKEY_F10          21
#define SONYPI_EVENT_FNKEY_F11          22
#define SONYPI_EVENT_FNKEY_F12          23
#define SONYPI_EVENT_FNKEY_1            24
#define SONYPI_EVENT_FNKEY_2            25
#define SONYPI_EVENT_FNKEY_D            26
#define SONYPI_EVENT_FNKEY_E            27
#define SONYPI_EVENT_FNKEY_F            28
#define SONYPI_EVENT_FNKEY_S            29
#define SONYPI_EVENT_FNKEY_B            30
#define SONYPI_EVENT_BLUETOOTH_PRESSED      31

gint sonypi_fd;
fd_set sonypi_fdset;

void sjog_sonypi_init();
void sjog_sonypi_read();

#endif

==> sjog_0.5-14.tar.gz: sjog-0.5/src/sjog_sonypi.h <==
#ifndef _SJOG_SONYPI_H
#define _SJOG_SONYPI_H 1

#include "sjog.h"

#define SONYPI_EVENT_JOGDIAL_DOWN        1
#define SONYPI_EVENT_JOGDIAL_UP          2
#define SONYPI_EVENT_JOGDIAL_DOWN_PRESSED    3
#define SONYPI_EVENT_JOGDIAL_UP_PRESSED      4
#define SONYPI_EVENT_JOGDIAL_PRESSED         5
#define SONYPI_EVENT_JOGDIAL_RELEASED        6
#define SONYPI_EVENT_CAPTURE_PRESSED         7
#define SONYPI_EVENT_CAPTURE_RELEASED        8
#define SONYPI_EVENT_CAPTURE_PARTIALPRESSED  9
#define SONYPI_EVENT_CAPTURE_PARTIALRELEASED    10
#define SONYPI_EVENT_FNKEY_ESC          11
#define SONYPI_EVENT_FNKEY_F1           12
#define SONYPI_EVENT_FNKEY_F2           13
#define SONYPI_EVENT_FNKEY_F3           14
#define SONYPI_EVENT_FNKEY_F4           15
#define SONYPI_EVENT_FNKEY_F5           16
#define SONYPI_EVENT_FNKEY_F6           17
#define SONYPI_EVENT_FNKEY_F7           18
#define SONYPI_EVENT_FNKEY_F8           19
#define SONYPI_EVENT_FNKEY_F9           20
#define SONYPI_EVENT_FNKEY_F10          21
#define SONYPI_EVENT_FNKEY_F11          22
#define SONYPI_EVENT_FNKEY_F12          23
#define SONYPI_EVENT_FNKEY_1            24
#define SONYPI_EVENT_FNKEY_2            25
#define SONYPI_EVENT_FNKEY_D            26
#define SONYPI_EVENT_FNKEY_E            27
#define SONYPI_EVENT_FNKEY_F            28
#define SONYPI_EVENT_FNKEY_S            29
#define SONYPI_EVENT_FNKEY_B            30
#define SONYPI_EVENT_BLUETOOTH_PRESSED      31

#define SONYPI_EVENT_BACK_PRESSED		35
#define SONYPI_EVENT_LID_CLOSED			36
#define SONYPI_EVENT_LID_OPENED			37
#define SONYPI_EVENT_HELP_PRESSED		40
#define SONYPI_EVENT_FNKEY            		41
#define SONYPI_EVENT_FNKEY_ZOOM			50
#define SONYPI_EVENT_FNKEY_THUMBPHRASE		51

gint sonypi_fd;
fd_set sonypi_fdset;

void sjog_sonypi_init();
void sjog_sonypi_read();

#endif
